@@ -226,7 +226,7 @@ class Transport(base.Transport):
         """Establish connection to the AMQP broker."""
         conninfo = self.client
         if not conninfo.hostname:
-            raise KeyError("Missing hostname for AMQP connection.")
+            conninfo.hostname = "localhost"
         if conninfo.userid is None:
             conninfo.userid = "guest"
         if conninfo.password is None:
